==> xl-react-components-0.16.62.tgz: package/app/pages/playground/spinner-test-component.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {localeMessages} from '../../services/locale-service';
import {XlReactWidgetSpinner} from '../../xl-react-widget/xl-react-widget-spinner/xl-react-widget-spinner';
import ToggleComponent from '../playground/toggle-component';
import ElementNavTitle from './element-nav-title';

import './spinner-test-component.less';

export class SpinnerTestComponent extends Component {
    static propTypes = {
        className: PropTypes.string,
        currentState: PropTypes.object.isRequired,
        modelName: PropTypes.string.isRequired,
        showBindings: PropTypes.bool,
        updateState: PropTypes.func.isRequired
    };

    onToggleOverlay = () => {
        const {modelName, updateState, currentState} = this.props;
        updateState(modelName, {
            ...currentState[modelName],
            overlay: !currentState[modelName].overlay
        });
    };

    render() {
        const {currentState, showBindings, modelName, className} = this.props;
        const model = currentState[modelName];
        const {navigationDescription, navigationTitle, overlay, type, show} = model;

        const toggleComponent = (handler, label, clazzName, checked = false) =>
            <ToggleComponent checked={checked} clazzName={clazzName} handleToggle={handler} label={label}/>;

        const displayBindings = () => showBindings ? <div className="testBindings">
            <div>
                {toggleComponent(this.onToggleOverlay, 'Overlay', 'spinner-overlay', model.overlay)}
            </div>
        </div> : null;

        return <div>
            <ElementNavTitle
                description={navigationDescription}
                modelName={modelName}
                title={navigationTitle}
                type={type}
            />
            <div className={className}>
                <div className="testComponent spinner-test-component">
                    <XlReactWidgetSpinner message={localeMessages.spinnerMessage} overlay={overlay} show={show}/>
                    {overlay && <div>
                        Content
                    </div>}
                </div>
                {displayBindings()}
            </div>
        </div>;
    }
}

==> xl-react-components-0.21.12.tgz: package/app/pages/playground/spinner-test-component.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {localeMessages} from '../../services/locale-service';
import {XlReactWidgetSpinner} from '../../xl-react-widget/xl-react-widget-spinner/xl-react-widget-spinner';
import ToggleComponent from '../playground/toggle-component';
import ElementNavTitle from './element-nav-title';

import './spinner-test-component.less';

export class SpinnerTestComponent extends Component {
    static propTypes = {
        className: PropTypes.string,
        currentState: PropTypes.object.isRequired,
        modelName: PropTypes.string.isRequired,
        showBindings: PropTypes.bool,
        updateState: PropTypes.func.isRequired
    };

    onToggleOverlay = () => {
        const {modelName, updateState, currentState} = this.props;
        updateState(modelName, {
            ...currentState[modelName],
            overlay: !currentState[modelName].overlay
        });
    };

    render() {
        const {currentState, showBindings, modelName, className} = this.props;
        const model = currentState[modelName];
        const {navigation: {description, title, type}, overlay, show} = model;

        const toggleComponent = (handler, label, clazzName, checked = false) =>
            <ToggleComponent checked={checked} clazzName={clazzName} handleToggle={handler} label={label}/>;

        const displayBindings = () => showBindings ? <div className="testBindings">
            <div>
                {toggleComponent(this.onToggleOverlay, 'Overlay', 'spinner-overlay', model.overlay)}
            </div>
        </div> : null;

        return <div>
            <ElementNavTitle
                description={description}
                modelName={modelName}
                title={title}
                type={type}
            />
            <div className={className}>
                <div className="testComponent spinner-test-component">
                    <XlReactWidgetSpinner message={localeMessages.spinnerMessage} overlay={overlay} show={show}/>
                    {overlay && <div>
                        Content
                    </div>}
                </div>
                {displayBindings()}
            </div>
        </div>;
    }
}
